@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2009 Julien Danjou
--- @release v3.4.9
+-- @release v3.4.10
 ---------------------------------------------------------------------------
 
 local client = client
@@ -13,21 +13,31 @@ local atag = require("awful.tag")
 -- on event such as tag switching, client unmanaging, etc.
 module("awful.autofocus")
 
--- Give focus on tag selection change.
+-- Give focus when clients appear/disappear.
 -- @param obj An object that should have a .screen property.
 local function check_focus(obj)
+    -- When no visible client has the focus...
     if not client.focus or not client.focus:isvisible() then
         local c = aclient.focus.history.get(obj.screen, 0)
         if c then client.focus = c end
-    elseif client.focus and client.focus.screen ~= obj.screen then
-        local c = aclient.focus.history.get(obj.screen, 0)
-        if c then client.focus = c end
     end
 end
 
-atag.attached_add_signal(nil, "property::selected", check_focus)
+-- Give focus on tag selection change.
+-- @param obj An object that should have a .screen property.
+local function check_focus_screen(obj)
+    check_focus(obj)
+    if client.focus and client.focus.screen ~= obj.screen then
+        local c = nil
+        c = aclient.focus.history.get(obj.screen, 0)
+        if c then client.focus = c end
+    end
+end
+
+atag.attached_add_signal(nil, "property::selected", check_focus_screen)
 client.add_signal("unmanage", check_focus)
 client.add_signal("new", function(c)
+    c:add_signal("tagged", check_focus)
     c:add_signal("untagged", check_focus)
     c:add_signal("property::hidden", check_focus)
     c:add_signal("property::minimized", check_focus)
