@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.9
+-- @release v3.4.10
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -56,7 +56,8 @@ function urgent.get()
 end
 
 --- Jump to the client that received the urgent hint first.
-function urgent.jumpto()
+-- @param merge If true then merge tags when clients are not visible.
+function urgent.jumpto(merge)
     local c = urgent.get()
     if c then
         local s = capi.client.focus and capi.client.focus.screen or capi.mouse.screen
@@ -64,10 +65,17 @@ function urgent.jumpto()
         if s ~= c.screen then
             capi.mouse.screen = c.screen
         end
-        -- focus the tag only if the client is not sticky
-        if not c.sticky then
-           tag.viewonly(c:tags()[1])
+
+        -- Try to make client visible, this also covers e.g. sticky
+        local t = c:tags()[1]
+        if t and not c:isvisible() then
+            if merge then
+                t.selected = true
+            else
+                tag.viewonly(t)
+            end
         end
+
         -- focus the client
         capi.client.focus = c
         c:raise()
@@ -627,8 +635,8 @@ end
 function floating.toggle(c)
     local c = c or capi.client.focus
     -- If it has been set to floating
-    if property.get(c, "floating") then
-        floating.set(c, nil)
+    if floating.get(c) then
+        floating.set(c, false)
     else
         floating.set(c, true)
     end
@@ -640,6 +648,28 @@ function floating.delete(c)
     floating.set(c, nil)
 end
 
+--- Restore (=unminimize) a random client.
+-- @param s The screen to use.
+-- @return True if some client was restored.
+function restore(s)
+    local s = s or (capi.client.focus and capi.client.focus.screen) or capi.mouse.screen
+    local cls = capi.client.get(s)
+    local tags = tag.selectedlist(s)
+    local mcls = {}
+    for k, c in pairs(cls) do
+        local ctags = c:tags()
+        if c.minimized then
+            for k, t in ipairs(tags) do
+                if util.table.hasitem(ctags, t) then
+                    c.minimized = false
+                    return true
+                end
+            end
+        end
+    end
+    return false
+end
+
 -- Normalize a set of numbers to 1
 -- @param set the set of numbers to normalize
 -- @param num the number of numbers to normalize
