@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.9
+-- @release v3.4.10
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -110,6 +110,8 @@ function client.snap(c, snap, x, y, fixed_x, fixed_y)
     local c = c or client.focus
     local cur_geom = c:geometry()
     local geom = c:geometry()
+    geom.width = geom.width + (2 * c.border_width)
+    geom.height = geom.height + (2 * c.border_width)
     local edge = "none"
     local edge2 = "none"
     geom.x = x or geom.x
@@ -136,12 +138,20 @@ function client.snap(c, snap, x, y, fixed_x, fixed_y)
         c:struts(struts)
     end
 
+    geom.x = geom.x - (2 * c.border_width)
+    geom.y = geom.y - (2 * c.border_width)
+
     for k, snapper in ipairs(aclient.visible(c.screen)) do
         if snapper ~= c then
             geom = snap_outside(geom, snapper:geometry(), snap)
         end
     end
 
+    geom.width = geom.width - (2 * c.border_width)
+    geom.height = geom.height - (2 * c.border_width)
+    geom.x = geom.x + (2 * c.border_width)
+    geom.y = geom.y + (2 * c.border_width)
+
     -- It's easiest to undo changes afterwards if they're not allowed
     if fixed_x then geom.x = cur_geom.x end
     if fixed_y then geom.y = cur_geom.y end
